
import 'dart:async';

import 'package:flutter_bloc/flutter_bloc.dart';

import 'package:hub/shared/components/molecules/menu/data/repositories/menu_repository_impl.dart';
import 'package:hub/shared/components/molecules/menu/index.dart';
import 'package:hub/shared/components/molecules/modules/index.dart';

import 'package:flutter_bloc/flutter_bloc.dart';


class MenuEvent {}

class MenuState {
  final List<MenuItem?> menuEntries;
  final bool isGrid;

  MenuState({this.menuEntries = const [], this.isGrid = false});

  MenuState copyWith({List<MenuItem?>? menuEntries, bool? isGrid}) {
    return MenuState(
      menuEntries: menuEntries ?? this.menuEntries,
      isGrid: isGrid ?? this.isGrid,
    );
  }
}

class MenuBloc extends Bloc<MenuEvent, MenuState> {
  final MenuView style;
  final EnumMenuItem item;
  final List<MenuEntry> menuOptions;
  late StreamSubscription<void> _completer;


  MenuBloc({required this.style, required this.item, required this.menuOptions}) : super(MenuState()) {
    on<MenuEvent>((event, emit) async {
      await LicenseRemoteDataSourceImpl().waitForSaveCompletion();
      final entries = await MenuRepositoryImpl().generateMenuEntries(menuOptions, item);
      emit(state.copyWith(menuEntries: entries));
    });

    _completer = LicenseRemoteDataSourceImpl().streamCompleterController.listen((_) {
      add(MenuEvent());
    });
  }

  @override
  Future<void> close() {
    _completer.cancel();
    return super.close();
  }
  

}
