import 'package:hub/shared/components/molecules/modules/data/data_sources/license_local_data_source.dart';
import 'package:hub/shared/components/molecules/modules/data/data_sources/license_remote_data_source.dart';
import 'package:hub/shared/components/molecules/modules/domain/respositories/license_repository.dart';
import 'package:hub/shared/helpers/database/database_helper.dart';
import 'package:rxdart/rxdart.dart';
import 'package:sqflite/sqflite.dart';

typedef LicenseStatus = bool;

class LicenseRepositoryImpl implements LicenseRepository {
  final LicenseLocalDataSource localDataSource = LicenseLocalDataSourceImpl();
  final LicenseRemoteDataSource remoteDataSource = LicenseRemoteDataSourceImpl();
  final Database database = DatabaseStorage.database;

  LicenseRepositoryImpl();

  static final license = BehaviorSubject<LicenseStatus>();
  static get stream => license.stream;

  Future<bool> updateLicense() async {
    final bool isNewVersion = await localDataSource.isNewVersion();
    await remoteDataSource.setupLicense(database, isNewVersion);
        if (isNewVersion) {
          return await remoteDataSource.fetchLicenses(isNewVersion);
        }
        return false;

  }

  Future<void> cleanLicense() async {
    return await remoteDataSource.cleanLicense();
  }

  Future<String?> getLicense(String key) async {
    return await localDataSource.get(key);
  }

  Future<void> setLicense<T>(String key, T value) async {
    return await localDataSource.set(key, value);
  }
}
